# load package if isn't loaded
package require VRS

# create view
set view [new SceneThing]
$view append [ new Camera {0 0 -2} { 0 0 0 } 60 ]

# create the scene
set scene [new SceneThing $view ]
$scene append   [new DistantLight { 1  1  1 } {1 1 1 1} 0.8 1]
$scene append   [new PointLight { 0  1  -2 }]


# create a thing for the billboard
set billboard [new SceneThing]
$billboard append [new ColorAttribute {1 1 1 1}]

# insert 3 lines  x-axis red  y-axis green  z-axis blue }
set itr [VectorItr { -1  0  0 } {  1  0  0 } \
				   {  0 -1  0 } {  0  1  0 } \
				   {  0  0 -1 } {  0  0  1 }]
set axises [new SceneThing $billboard]
$axises append [new LineSet PolygonSet::Lines $itr ]

# insert a textured quad
set texQuad [ new SceneThing $billboard ]
$texQuad append   [new LightModelGL false]
$texQuad append   [new ImageTexture2DGL [ObjectLoader readFile pics/vrs.ppm] ]
$texQuad append   [new PolygonSet PolygonSet::Quads \
		[VectorItr { 0.707  -0.707  -0.1 } { 0.707   0.707  -0.1 } {  -0.707   0.707  -0.1 } {  -0.707  -0.707  -0.1 }] \
		NULL \
		[VectorItr { 1  0  0 } { 1  1  0 } { 0  1  0 } { 0  0  0}]]

# insert a transparent sphere
set transSphere [new SceneThing  $billboard ]
$transSphere append   [new ColorAttribute { 1  1  1  0.25} ]   
$transSphere append   [new Sphere]

# create the main-thing
set main [ new SceneAdjuster $scene [new Box { -1  -1  -1 }  { 1  1  1 }] ]

# insert the transparent cross
set cross [new SceneThing $main ] 
$cross append   [new ColorAttribute { 1  1  1  0.25 } ]   
$cross append   [new Cylinder { -1.02  0  0 }  { 1.02  0  0 }  0.2 ]   
$cross append   [new Cylinder { 0  -1.02  0 }  { 0  1.02  0 }  0.2 ]  

# insert the upper billboard  cylindrical 
set upperBill [new SceneThing $main ]
$upperBill append [new Billboard Billboard::Cylindrical  { 0  2  0 }]
$upperBill append $billboard  

# insert the lower billboard  cylindrical 
set lowerBill [new SceneThing $main ]
$lowerBill append [new Billboard Billboard::Cylindrical  { 0  -2  0 }  ]
$lowerBill append [new Rotation { 0  0  1 }  {0 0 0} 180]
$lowerBill append $billboard  

# insert the left billboard spherical 
set leftBill [new SceneThing $main]
$leftBill append [new Billboard Billboard::Spherical  {-2  0  0 }  ]
$leftBill append $billboard  

# insert the right billboard spherical 
set rightBill [new SceneThing $main]  
$rightBill append [new Billboard Billboard::Spherical  { 2  0  0 } ]
$rightBill append $billboard  

# make the OpenGL canvas

set canvas [new TclCanvas .tkbillboard  400  400  GLCanvas::RGBADD ]

set config [new SceneConfiguration]
$config append [new TransparencyTechniqueGL]

$canvas append $config
$canvas append $view  
$canvas append [new TrackBall $scene]

frame .mbar -border 1 -relief raised
menubutton .mbar.file -text File -menu .mbar.file.m

menu .mbar.file.m
.mbar.file.m add command -label "Quit" -command "destroy . ; VRS cleanup"

pack .mbar.file -side left
pack .mbar -fill x

#
# CANVAS
#
pack .tkbillboard -fill both -expand yes





